@@ -1,8 +1,8 @@
 from .all import AllTransform
 from .crop import Crop
-from .duplicate_channels import DuplicateChannels
 from .loudness import Loudness
 from .overlap_channels import OverlapChannels
 from .randomcrop import RandomCrop
 from .resample import Resample
 from .scale import Scale
+from .stereo import Stereo
