@@ -4,12 +4,12 @@ from torch import Tensor, nn
 
 from ..utils import exists
 from .crop import Crop
-from .duplicate_channels import DuplicateChannels
 from .loudness import Loudness
 from .overlap_channels import OverlapChannels
 from .randomcrop import RandomCrop
 from .resample import Resample
 from .scale import Scale
+from .stereo import Stereo
 
 
 class AllTransform(nn.Module):
@@ -21,7 +21,7 @@ class AllTransform(nn.Module):
         random_crop_size: Optional[int] = None,
         loudness: Optional[int] = None,
         scale: Optional[float] = None,
-        duplicate_channels: bool = False,
+        use_stereo: bool = False,
         overlap_channels: bool = False,
     ):
         super().__init__()
@@ -39,7 +39,7 @@ class AllTransform(nn.Module):
             RandomCrop(random_crop_size) if exists(random_crop_size) else nn.Identity(),
             Crop(crop_size) if exists(crop_size) else nn.Identity(),
             OverlapChannels() if overlap_channels else nn.Identity(),
-            DuplicateChannels() if duplicate_channels else nn.Identity(),
+            Stereo() if use_stereo else nn.Identity(),
             Loudness(sampling_rate=target_rate, target=loudness)  # type: ignore
             if exists(loudness)
             else nn.Identity(),
